@@ -1,6 +1,6 @@
 const Board = require("./board");
 const Expander = require("./expander");
-const Emitter = require("events");
+const Emitter = require("./mixins/emitter");
 const { constrain, fma, int16, sum, toFixed, RAD_TO_DEG } = require("./fn");
 
 const priv = new Map();
