@@ -1,4 +1,4 @@
-const Emitter = require("events");
+const Emitter = require("./mixins/emitter");
 const chalk = require("chalk");
 const Collection = require("./mixins/collection");
 const Fn = require("./fn");
@@ -471,11 +471,6 @@ function finalizeAndBroadcast(data, type, io) {
   }
 }
 
-// Inherit event api
-// util.inherits(Board, Emitter);
-
-
-
 /**
  * Pass through methods
  */
