@@ -1,5 +1,5 @@
 const Board = require("./board");
-const Emitter = require("events");
+const Emitter = require("./mixins/emitter");
 const {int16, RAD_TO_DEG, TAU} = require("./fn");
 const priv = new Map();
 
