@@ -1,5 +1,5 @@
 const Board = require("./board");
-const Emitter = require("events");
+const Emitter = require("./mixins/emitter");
 const sleep = require("./sleep");
 const Fn = require("./fn");
 const priv = new Map();
