@@ -1,5 +1,5 @@
 const Board = require("./board");
-const Emitter = require("events");
+const Emitter = require("./mixins/emitter");
 const Fn = require("./fn");
 const { scale, toFixed, uint16 } = Fn;
 const priv = new Map();
