@@ -1,6 +1,6 @@
 const Board = require("./board");
 const Collection = require("./mixins/collection");
-const Emitter = require("events");
+const Emitter = require("./mixins/emitter");
 const EVS = require("./evshield");
 const Expander = require("./expander.js");
 const Fn = require("./fn");
