@@ -1,6 +1,6 @@
 const Board = require("./board");
-const Emitter = require("events");
-const Withinable = require("./mixins/within");
+const EventEmitter = require("events");
+const Withinable = require("./mixins/withinable");
 const {
   toFixed,
   POW_2_16,
@@ -283,7 +283,7 @@ Drivers.get = (board, driverName, options) => {
   const key = `${driverName}_${options.pin}`;
 
   if (!drivers[key]) {
-    driver = new Emitter();
+    driver = new EventEmitter();
     Object.defineProperties(driver, Drivers[driverName]);
     driver.initialize(board, options);
     drivers[key] = driver;
